@@ -5,12 +5,6 @@ Parses the computed data from VASP defect calculations.
 # from __future__ import unicode_literals
 from __future__ import division
 
-__author__ = "Bharat Medasani, Nils Zimmermann, Danny Broberg"
-__copyright__ = "MIT License"
-__version__ = "0.0.1"
-__maintainer__ = "Seán Kavanagh"
-__email__ = "sean.kavanagh.19@ucl.ac.uk"
-__date__ = "May 19, 2020"
 
 import glob
 import logging
@@ -31,6 +25,13 @@ from pymatgen.io.vasp.outputs import Vasprun, Locpot, Outcar, Poscar
 
 from doped.pycdt.core import chemical_potentials
 
+angstrom = "\u212B" # unicode symbol for angstrom to print in strings
+
+
+def custom_formatwarning(msg, *args, **kwargs):
+    f"""Reformat warnings to just print the warning message"""
+    return f"{msg}\n"
+warnings.formatwarning = custom_formatwarning
 
 def convert_cd_to_de(cd, b_cse):
     """
@@ -93,7 +94,7 @@ def convert_cd_to_de(cd, b_cse):
 
 
 def get_vasprun(vasprun_path, **kwargs):
-    """ Read the vasprun.xml(.gz) file as a pymatgen Locpot object """
+    """Read the vasprun.xml(.gz) file as a pymatgen Locpot object"""
     warnings.filterwarnings(
         "ignore", category=UnknownPotcarWarning
     )  # Ignore POTCAR warnings when loading vasprun.xml
@@ -112,7 +113,7 @@ def get_vasprun(vasprun_path, **kwargs):
 
 
 def get_locpot(locpot_path):
-    """ Read the LOCPOT(.gz) file as a pymatgen Locpot object """
+    """Read the LOCPOT(.gz) file as a pymatgen Locpot object"""
     if os.path.exists(locpot_path):
         locpot = Locpot.from_file(locpot_path)
     elif os.path.exists(locpot_path + ".gz"):
@@ -220,19 +221,25 @@ class SingleDefectParser:
 
         defect_index_sc_coords = None
         transformation_path = os.path.join(path_to_defect, "transformation.json")
-        if not os.path.exists(transformation_path): # try next folder up
+        if not os.path.exists(transformation_path):  # try next folder up
             orig_transformation_path = transformation_path
             transformation_path = os.path.join(
                 os.path.dirname(os.path.normpath(path_to_defect)), "transformation.json"
             )
             if os.path.exists(transformation_path):
-                print("No transformation file found at {}, but found one at {}. "
-                      "Using this for defect parsing.".format(orig_transformation_path, transformation_path))
+                print(
+                    "No transformation file found at {}, but found one at {}. "
+                    "Using this for defect parsing.".format(
+                        orig_transformation_path, transformation_path
+                    )
+                )
 
         if os.path.exists(transformation_path):
             tf = loadfn(transformation_path)
             site = tf["defect_supercell_site"]
-            if defect_type == "Vacancy": # should we also search the bulk structure for substitutions?
+            if (
+                defect_type == "Vacancy"
+            ):  # should we also search the bulk structure for substitutions?
                 poss_deflist = sorted(
                     bulk_sc_structure.get_sites_in_sphere(site.coords, 0.2, include_index=True),
                     key=lambda x: x[1],
@@ -241,7 +248,7 @@ class SingleDefectParser:
             else:
                 poss_deflist = sorted(
                     initial_defect_structure.get_sites_in_sphere(
-                        site.coords, 0.2, include_index=True
+                        site.coords, 2.5, include_index=True
                     ),
                     key=lambda x: x[1],
                 )
@@ -251,6 +258,15 @@ class SingleDefectParser:
                     "{} specified defect site {}, but could not find it in {}."
                     " Abandoning parsing".format(transformation_path, site, searched)
                 )
+            elif poss_deflist[0][1] > 1:
+                site_matched_defect = poss_deflist[0]  # pymatgen Neighbor object
+                offsite_warning = (
+                    f"Site-matching has determined {site_matched_defect.species} at "
+                    f"{site_matched_defect.coords} as the defect site, located "
+                    f"{site_matched_defect.nn_distance:.2f} {angstrom} from its initial "
+                    f"position. This may incur small errors in the charge correction."
+                )
+                warnings.warn(message=offsite_warning)
             defect_index_sc_coords = poss_deflist[0][2]
         else:
             print(
@@ -503,6 +519,7 @@ class SingleDefectParser:
 
             elif self.defect_entry.site:
                 defect_frac_sc_coords = self.defect_entry.site.frac_coords
+                defect_type = self.defect_entry.defect.as_dict()["@class"]
                 if defect_type == "Vacancy":
                     poss_deflist = sorted(
                         bulk_sc_structure.get_sites_in_sphere(
@@ -514,7 +531,7 @@ class SingleDefectParser:
                 else:
                     poss_deflist = sorted(
                         initial_defect_structure.get_sites_in_sphere(
-                            self.defect_entry.site.coords, 0.2, include_index=True
+                            self.defect_entry.site.coords, 2.5, include_index=True
                         ),
                         key=lambda x: x[1],
                     )
@@ -522,8 +539,19 @@ class SingleDefectParser:
                 if not poss_deflist:
                     raise ValueError(
                         "Could not find defect site {} in {}, abandoning parsing".format(
-                            self.defect_entry.site, searched)
+                            self.defect_entry.site, searched
+                        )
                     )
+                elif poss_deflist[0][1] > 1:
+                    site_matched_defect = poss_deflist[0] # pymatgen Neighbor object
+                    offsite_warning = (
+                        f"Site-matching has determined {site_matched_defect.species} at "
+                        f"{site_matched_defect.coords} as the defect site, located "
+                        f"{site_matched_defect.nn_distance:.2f} {angstrom} from its initial "
+                        f"position. This may incur small errors in the charge correction."
+                    )
+                    warnings.warn(message=offsite_warning)
+
                 defect_index_sc_coords = poss_deflist[0][2]
 
             else:
@@ -762,7 +790,7 @@ You can also change the DefectCompatibility() tolerance settings via the `compat
 in `SingleDefectParser.from_paths()`.
 Watch out that if `num_hole_vbm` or `num_elec_cbm` are greater than the free_chg_cutoff (default
 2.1), charge correction will not be applied."""
-            warnings.warn(message=delocalized_warning, stacklevel=1)
+            warnings.warn(message=delocalized_warning)
 
 
 class PostProcess:
